<?php

/**
 * This file is part of the composer-changelogs project.
 *
 * (c) Loïck Piera <pyrech@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Pyrech\ComposerChangelogs\OperationHandler;

use Composer\DependencyResolver\Operation\OperationInterface;
use Pyrech\ComposerChangelogs\UrlGenerator\UrlGenerator;

interface OperationHandler
{
    /**
     * Return whether the handler supports the given operation.
     *
     * @param OperationInterface $operation
     *
     * @return bool
     */
    public function supports(OperationInterface $operation);

    /**
     * Extract the source url for the package related to the given operation.
     *
     * @param OperationInterface $operation
     *
     * @return string
     */
    public function extractSourceUrl(OperationInterface $operation);

    /**
     * Generate output for the given operation, with some links generated by
     * the url generator.
     *
     * @param OperationInterface $operation
     * @param UrlGenerator|null  $urlGenerator
     *
     * @return array
     */
    public function getOutput(OperationInterface $operation, UrlGenerator $urlGenerator = null);
}
